==> org.apache.poi.source_5.3.0.v20240703-1000.jar: org/apache/poi/poifs/filesystem/TempFilePOIFSFileSystem.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */
package org.apache.poi.poifs.filesystem;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.poi.poifs.nio.FileBackedDataSource;
import org.apache.poi.util.Beta;
import org.apache.poi.util.TempFile;

import java.io.File;
import java.io.IOException;

/**
 * An experimental POIFSFileSystem to support the encryption of large files
 *
 * @since 4.1.1
 */
@Beta
public class TempFilePOIFSFileSystem extends POIFSFileSystem {
    private static final Logger LOG = LogManager.getLogger(TempFilePOIFSFileSystem.class);
    File tempFile;

    @Override
    protected void createNewDataSource() {
        try {
            tempFile = TempFile.createTempFile("poifs", ".tmp");
            _data = new FileBackedDataSource(tempFile, false);
        } catch (IOException e) {
            throw new IllegalStateException("Failed to create data source", e);
        }
    }

    @Override
    public void close() throws IOException {
        if (tempFile != null && tempFile.exists()) {
            if (!tempFile.delete()) {
                LOG.atDebug().log("temp file was already deleted (probably due to previous call to close this resource)");
            }
        }
        super.close();
    }

}

==> org.apache.poi.source_5.4.1.v20250715-1000.jar: org/apache/poi/poifs/filesystem/TempFilePOIFSFileSystem.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */
package org.apache.poi.poifs.filesystem;

import org.apache.logging.log4j.Logger;
import org.apache.poi.logging.PoiLogManager;
import org.apache.poi.poifs.nio.FileBackedDataSource;
import org.apache.poi.util.Beta;
import org.apache.poi.util.TempFile;

import java.io.File;
import java.io.IOException;

/**
 * An experimental POIFSFileSystem to support the encryption of large files
 *
 * @since 4.1.1
 */
@Beta
public class TempFilePOIFSFileSystem extends POIFSFileSystem {
    private static final Logger LOG = PoiLogManager.getLogger(TempFilePOIFSFileSystem.class);
    File tempFile;

    @Override
    protected void createNewDataSource() {
        try {
            tempFile = TempFile.createTempFile("poifs", ".tmp");
            _data = new FileBackedDataSource(tempFile, false);
        } catch (IOException e) {
            throw new IllegalStateException("Failed to create data source", e);
        }
    }

    @Override
    public void close() throws IOException {
        if (tempFile != null && tempFile.exists()) {
            if (!tempFile.delete()) {
                LOG.atDebug().log("temp file was already deleted (probably due to previous call to close this resource)");
            }
        }
        super.close();
    }

}
